'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

const index = require('./index-bc6c9f09.js');

var Variants;
(function (Variants) {
    Variants["primary"] = "primary";
    Variants["secondary"] = "secondary";
    Variants["success"] = "success";
    Variants["danger"] = "danger";
    Variants["warning"] = "warning";
    Variants["info"] = "info";
    Variants["light"] = "light";
    Variants["dark"] = "dark";
})(Variants || (Variants = {}));
var AdditionalVariants;
(function (AdditionalVariants) {
    AdditionalVariants["link"] = "link";
})(AdditionalVariants || (AdditionalVariants = {}));
var Sizes;
(function (Sizes) {
    Sizes["large"] = "lg";
    Sizes["small"] = "sm";
})(Sizes || (Sizes = {}));

const bxAlertCss = "bx-alert{display:block}";

const BxAlert = class {
    constructor(hostRef) {
        index.registerInstance(this, hostRef);
        this.variant = Variants.primary;
        this.dismissible = false;
        this.closing = index.createEvent(this, "closing", 7);
        this.closed = index.createEvent(this, "closed", 7);
    }
    dismissibleContent() {
        return (index.h("button", { type: "button", class: "close", "aria-label": "Close", onClick: this.close.bind(this) }, index.h("span", { "aria-hidden": "true" }, "\u00D7")));
    }
    render() {
        let alertClass = `alert alert-${this.variant}`;
        alertClass = this.dismissible ? `${alertClass} alert-dismissible show fade` : alertClass; // append dismissible classess
        return (index.h(index.Host, { class: alertClass, role: "alert" }, this.text ? this.text : index.h("slot", null), this.dismissible ? this.dismissibleContent() : null));
    }
    // methods
    async alert() {
        return this.dismissible = true;
    }
    async close() {
        this.closing.emit();
        this.element.classList.remove('show');
        window.setTimeout(() => {
            this.closed.emit();
            this.element.remove();
        }, 200);
    }
    async dispose() {
        this.element.remove();
    }
    get element() { return index.getElement(this); }
};
BxAlert.style = bxAlertCss;

const bxBadgeCss = ":host{display:block}";

const BxBadge = class {
    constructor(hostRef) {
        index.registerInstance(this, hostRef);
        this.variant = Variants.primary;
        this.pill = false;
    }
    render() {
        let badgeClass = `badge ${this.pill ? 'badge-pill' : ''} badge-${this.variant}`;
        let content = this.text ? this.text : index.h("slot", null);
        return (this.link
            ? index.h("a", { href: this.link, class: badgeClass, target: this.target }, content)
            : index.h(index.Host, { class: badgeClass }, content));
    }
};
BxBadge.style = bxBadgeCss;

const bxBreadcrumbCss = "bx-breadcrumb .breadcrumb-item--custom+.breadcrumb-item--custom::before{content:attr(data-separator)}";

const BxBreadcrumb = class {
    constructor(hostRef) {
        index.registerInstance(this, hostRef);
        this.separator = '/';
        this.clicked = index.createEvent(this, "clicked", 7);
    }
    componentWillLoad() {
        this.breadcrumbs = this.parseBreadcrumbs;
    }
    get parseBreadcrumbs() {
        return (typeof this.breadcrumbs === 'string')
            ? JSON.parse(this.breadcrumbs)
            : this.breadcrumbs;
    }
    computedBreadcrumbs() {
        try {
            let breadcrumbs = this.parseBreadcrumbs;
            let hasActive = Boolean(breadcrumbs.find(breadcrumb => breadcrumb.active));
            let computedbreadcrumbs = breadcrumbs.map((breadcrumb, index) => {
                breadcrumb.link = breadcrumb.link || `#${breadcrumb.text}`; // if not link add hashtag for label
                breadcrumb.active = hasActive ? breadcrumb.active : (breadcrumbs.length === index + 1); // if not active last level is active
                return breadcrumb;
            });
            return computedbreadcrumbs;
        }
        catch (e) {
            console.error('Invalid format passed for breadcrumbs', e.stack);
        }
    }
    generateBreadcrumb(breadcrumb) {
        let className = 'breadcrumb-item breadcrumb-item--custom';
        className = breadcrumb.active ? `${className} active` : className;
        return (index.h("li", { class: className, "aria-current": breadcrumb.active ? 'page' : null, "data-separator": this.separator }, breadcrumb.active
            ? index.h("span", null, breadcrumb.text)
            : index.h("a", { href: breadcrumb.link, onClick: this.onClick.bind(this, breadcrumb) }, breadcrumb.text)));
    }
    onClick(breadcrumb) {
        this.makeActive(breadcrumb);
        this.clicked.emit(breadcrumb);
    }
    makeActive(selected) {
        let updatedBreadcrumbs = this.computedBreadcrumbs().map(breadcrumb => {
            breadcrumb.active = (breadcrumb.text === selected.text);
            return breadcrumb;
        });
        this.breadcrumbs = updatedBreadcrumbs;
    }
    render() {
        return (index.h("ol", { class: "breadcrumb" }, this.breadcrumbs
            ? this.computedBreadcrumbs().map(breadcrumb => {
                return this.generateBreadcrumb(breadcrumb);
            })
            : index.h("slot", null)));
    }
    async add(breadcrumb) {
        let breadCrumbs = this.computedBreadcrumbs();
        breadCrumbs.push(breadcrumb);
        this.breadcrumbs = breadCrumbs;
    }
    async active(text) {
        let breadcrumbs = this.computedBreadcrumbs().find(breadcrumb => breadcrumb.text === text);
        this.makeActive(breadcrumbs);
    }
    async delete(text) {
        let breadcrumbs = this.computedBreadcrumbs().filter(breadcrumb => breadcrumb.text !== text);
        this.breadcrumbs = breadcrumbs;
    }
    async dispose() {
        this.element.remove();
    }
    get element() { return index.getElement(this); }
};
BxBreadcrumb.style = bxBreadcrumbCss;

const bxButtonCss = ":host{display:block}";

const BxButton = class {
    constructor(hostRef) {
        index.registerInstance(this, hostRef);
        this.variant = Variants.primary;
        this.outline = false;
        this.block = false;
        this.active = false;
        this.disabled = false;
    }
    render() {
        let buttonClass = `btn btn-${this.outline ? 'outline-' : ''}${this.variant}`;
        buttonClass = this.size ? `${buttonClass} btn-${Sizes[this.size]}` : buttonClass;
        buttonClass = this.block ? `${buttonClass} btn-block` : buttonClass;
        buttonClass = this.active ? `${buttonClass} active` : buttonClass;
        buttonClass = this.disabled ? `${buttonClass} disabled` : buttonClass;
        let content = this.text ? this.text : index.h("slot", null);
        return (this.link
            ? index.h("a", { href: this.link, target: this.target, class: buttonClass, role: "button", tabindex: this.disabled ? '-1' : undefined, "aria-disabled": this.disabled ? 'true' : undefined }, content)
            : index.h(index.Host, { class: buttonClass, role: "button", disabled: this.disabled, "aria-disabled": this.disabled ? 'true' : undefined }, content));
    }
    async toggle() {
        this.active = true;
    }
    async dispose() {
        this.element.remove();
    }
    get element() { return index.getElement(this); }
};
BxButton.style = bxButtonCss;

const bxSpinnerCss = ":host{display:block}";

const BxSpinner = class {
    constructor(hostRef) {
        index.registerInstance(this, hostRef);
        this.variant = Variants.primary;
        this.small = false;
        this.grow = false;
    }
    render() {
        let spinnerType = `spinner-${this.grow ? 'grow' : 'border'}`;
        let spinnerSize = this.small ? `${spinnerType}-sm` : null;
        let spinnerClass = `${spinnerType} text-${this.variant} ${spinnerSize}`;
        return (index.h(index.Host, { class: spinnerClass, role: "status" }, index.h("span", { class: "sr-only" }, "Loading...")));
    }
    async dispose() {
        this.element.remove();
    }
    get element() { return index.getElement(this); }
};
BxSpinner.style = bxSpinnerCss;

exports.bx_alert = BxAlert;
exports.bx_badge = BxBadge;
exports.bx_breadcrumb = BxBreadcrumb;
exports.bx_button = BxButton;
exports.bx_spinner = BxSpinner;
