import { Component, h, Prop, Element, Host, Event, Method } from '@stencil/core';
import { Variants } from '../../shared/bootstrap.dto';
export class BxAlert {
    constructor() {
        this.variant = Variants.primary;
        this.dismissible = false;
    }
    dismissibleContent() {
        return (h("button", { type: "button", class: "close", "aria-label": "Close", onClick: this.close.bind(this) },
            h("span", { "aria-hidden": "true" }, "\u00D7")));
    }
    render() {
        let alertClass = `alert alert-${this.variant}`;
        alertClass = this.dismissible ? `${alertClass} alert-dismissible show fade` : alertClass; // append dismissible classess
        return (h(Host, { class: alertClass, role: "alert" },
            this.text ? this.text : h("slot", null),
            this.dismissible ? this.dismissibleContent() : null));
    }
    // methods
    async alert() {
        return this.dismissible = true;
    }
    async close() {
        this.closing.emit();
        this.element.classList.remove('show');
        window.setTimeout(() => {
            this.closed.emit();
            this.element.remove();
        }, 200);
    }
    async dispose() {
        this.element.remove();
    }
    static get is() { return "bx-alert"; }
    static get originalStyleUrls() { return {
        "$": ["bx-alert.css"]
    }; }
    static get styleUrls() { return {
        "$": ["bx-alert.css"]
    }; }
    static get properties() { return {
        "variant": {
            "type": "string",
            "mutable": false,
            "complexType": {
                "original": "Variants",
                "resolved": "Variants.danger | Variants.dark | Variants.info | Variants.light | Variants.primary | Variants.secondary | Variants.success | Variants.warning",
                "references": {
                    "Variants": {
                        "location": "import",
                        "path": "../../shared/bootstrap.dto"
                    }
                }
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": ""
            },
            "attribute": "variant",
            "reflect": false,
            "defaultValue": "Variants.primary"
        },
        "text": {
            "type": "string",
            "mutable": false,
            "complexType": {
                "original": "string",
                "resolved": "string",
                "references": {}
            },
            "required": false,
            "optional": true,
            "docs": {
                "tags": [],
                "text": ""
            },
            "attribute": "text",
            "reflect": false
        },
        "dismissible": {
            "type": "boolean",
            "mutable": false,
            "complexType": {
                "original": "boolean",
                "resolved": "boolean",
                "references": {}
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": ""
            },
            "attribute": "dismissible",
            "reflect": false,
            "defaultValue": "false"
        }
    }; }
    static get events() { return [{
            "method": "closing",
            "name": "closing",
            "bubbles": true,
            "cancelable": true,
            "composed": true,
            "docs": {
                "tags": [],
                "text": ""
            },
            "complexType": {
                "original": "void",
                "resolved": "void",
                "references": {}
            }
        }, {
            "method": "closed",
            "name": "closed",
            "bubbles": true,
            "cancelable": true,
            "composed": true,
            "docs": {
                "tags": [],
                "text": ""
            },
            "complexType": {
                "original": "void",
                "resolved": "void",
                "references": {}
            }
        }]; }
    static get methods() { return {
        "alert": {
            "complexType": {
                "signature": "() => Promise<boolean>",
                "parameters": [],
                "references": {
                    "Promise": {
                        "location": "global"
                    }
                },
                "return": "Promise<boolean>"
            },
            "docs": {
                "text": "",
                "tags": []
            }
        },
        "close": {
            "complexType": {
                "signature": "() => Promise<void>",
                "parameters": [],
                "references": {
                    "Promise": {
                        "location": "global"
                    }
                },
                "return": "Promise<void>"
            },
            "docs": {
                "text": "",
                "tags": []
            }
        },
        "dispose": {
            "complexType": {
                "signature": "() => Promise<void>",
                "parameters": [],
                "references": {
                    "Promise": {
                        "location": "global"
                    }
                },
                "return": "Promise<void>"
            },
            "docs": {
                "text": "",
                "tags": []
            }
        }
    }; }
    static get elementRef() { return "element"; }
}
