import { Component, h, Prop, Method, Element, Event } from '@stencil/core';
export class BxBreadcrumb {
    constructor() {
        this.separator = '/';
    }
    componentWillLoad() {
        this.breadcrumbs = this.parseBreadcrumbs;
    }
    get parseBreadcrumbs() {
        return (typeof this.breadcrumbs === 'string')
            ? JSON.parse(this.breadcrumbs)
            : this.breadcrumbs;
    }
    computedBreadcrumbs() {
        try {
            let breadcrumbs = this.parseBreadcrumbs;
            let hasActive = Boolean(breadcrumbs.find(breadcrumb => breadcrumb.active));
            let computedbreadcrumbs = breadcrumbs.map((breadcrumb, index) => {
                breadcrumb.link = breadcrumb.link || `#${breadcrumb.text}`; // if not link add hashtag for label
                breadcrumb.active = hasActive ? breadcrumb.active : (breadcrumbs.length === index + 1); // if not active last level is active
                return breadcrumb;
            });
            return computedbreadcrumbs;
        }
        catch (e) {
            console.error('Invalid format passed for breadcrumbs', e.stack);
        }
    }
    generateBreadcrumb(breadcrumb) {
        let className = 'breadcrumb-item breadcrumb-item--custom';
        className = breadcrumb.active ? `${className} active` : className;
        return (h("li", { class: className, "aria-current": breadcrumb.active ? 'page' : null, "data-separator": this.separator }, breadcrumb.active
            ? h("span", null, breadcrumb.text)
            : h("a", { href: breadcrumb.link, onClick: this.onClick.bind(this, breadcrumb) }, breadcrumb.text)));
    }
    onClick(breadcrumb) {
        this.makeActive(breadcrumb);
        this.clicked.emit(breadcrumb);
    }
    makeActive(selected) {
        let updatedBreadcrumbs = this.computedBreadcrumbs().map(breadcrumb => {
            breadcrumb.active = (breadcrumb.text === selected.text);
            return breadcrumb;
        });
        this.breadcrumbs = updatedBreadcrumbs;
    }
    render() {
        return (h("ol", { class: "breadcrumb" }, this.breadcrumbs
            ? this.computedBreadcrumbs().map(breadcrumb => {
                return this.generateBreadcrumb(breadcrumb);
            })
            : h("slot", null)));
    }
    async add(breadcrumb) {
        let breadCrumbs = this.computedBreadcrumbs();
        breadCrumbs.push(breadcrumb);
        this.breadcrumbs = breadCrumbs;
    }
    async active(text) {
        let breadcrumbs = this.computedBreadcrumbs().find(breadcrumb => breadcrumb.text === text);
        this.makeActive(breadcrumbs);
    }
    async delete(text) {
        let breadcrumbs = this.computedBreadcrumbs().filter(breadcrumb => breadcrumb.text !== text);
        this.breadcrumbs = breadcrumbs;
    }
    async dispose() {
        this.element.remove();
    }
    static get is() { return "bx-breadcrumb"; }
    static get originalStyleUrls() { return {
        "$": ["bx-breadcrumb.css"]
    }; }
    static get styleUrls() { return {
        "$": ["bx-breadcrumb.css"]
    }; }
    static get properties() { return {
        "separator": {
            "type": "string",
            "mutable": false,
            "complexType": {
                "original": "string",
                "resolved": "string",
                "references": {}
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": ""
            },
            "attribute": "separator",
            "reflect": false,
            "defaultValue": "'/'"
        },
        "breadcrumbs": {
            "type": "string",
            "mutable": false,
            "complexType": {
                "original": "Breadcrumb[] | string",
                "resolved": "Breadcrumb[] | string",
                "references": {
                    "Breadcrumb": {
                        "location": "import",
                        "path": "./bx-breadcrumb.dto"
                    }
                }
            },
            "required": false,
            "optional": true,
            "docs": {
                "tags": [],
                "text": ""
            },
            "attribute": "breadcrumbs",
            "reflect": false
        }
    }; }
    static get events() { return [{
            "method": "clicked",
            "name": "clicked",
            "bubbles": true,
            "cancelable": true,
            "composed": true,
            "docs": {
                "tags": [],
                "text": "A click event for breadcrumb items"
            },
            "complexType": {
                "original": "Breadcrumb",
                "resolved": "Breadcrumb",
                "references": {
                    "Breadcrumb": {
                        "location": "import",
                        "path": "./bx-breadcrumb.dto"
                    }
                }
            }
        }]; }
    static get methods() { return {
        "add": {
            "complexType": {
                "signature": "(breadcrumb: Breadcrumb) => Promise<void>",
                "parameters": [{
                        "tags": [],
                        "text": ""
                    }],
                "references": {
                    "Promise": {
                        "location": "global"
                    },
                    "Breadcrumb": {
                        "location": "import",
                        "path": "./bx-breadcrumb.dto"
                    }
                },
                "return": "Promise<void>"
            },
            "docs": {
                "text": "",
                "tags": []
            }
        },
        "active": {
            "complexType": {
                "signature": "(text: String) => Promise<void>",
                "parameters": [{
                        "tags": [],
                        "text": ""
                    }],
                "references": {
                    "Promise": {
                        "location": "global"
                    },
                    "String": {
                        "location": "global"
                    },
                    "Breadcrumb": {
                        "location": "import",
                        "path": "./bx-breadcrumb.dto"
                    }
                },
                "return": "Promise<void>"
            },
            "docs": {
                "text": "",
                "tags": []
            }
        },
        "delete": {
            "complexType": {
                "signature": "(text: String) => Promise<void>",
                "parameters": [{
                        "tags": [],
                        "text": ""
                    }],
                "references": {
                    "Promise": {
                        "location": "global"
                    },
                    "String": {
                        "location": "global"
                    },
                    "Breadcrumb": {
                        "location": "import",
                        "path": "./bx-breadcrumb.dto"
                    }
                },
                "return": "Promise<void>"
            },
            "docs": {
                "text": "",
                "tags": []
            }
        },
        "dispose": {
            "complexType": {
                "signature": "() => Promise<void>",
                "parameters": [],
                "references": {
                    "Promise": {
                        "location": "global"
                    }
                },
                "return": "Promise<void>"
            },
            "docs": {
                "text": "",
                "tags": []
            }
        }
    }; }
    static get elementRef() { return "element"; }
}
