import { Component, Host, h, Prop, Method, Element } from '@stencil/core';
import { Variants, Sizes } from '../../shared/bootstrap.dto';
export class BxButton {
    constructor() {
        this.variant = Variants.primary;
        this.outline = false;
        this.block = false;
        this.active = false;
        this.disabled = false;
    }
    render() {
        let buttonClass = `btn btn-${this.outline ? 'outline-' : ''}${this.variant}`;
        buttonClass = this.size ? `${buttonClass} btn-${Sizes[this.size]}` : buttonClass;
        buttonClass = this.block ? `${buttonClass} btn-block` : buttonClass;
        buttonClass = this.active ? `${buttonClass} active` : buttonClass;
        buttonClass = this.disabled ? `${buttonClass} disabled` : buttonClass;
        let content = this.text ? this.text : h("slot", null);
        return (this.link
            ? h("a", { href: this.link, target: this.target, class: buttonClass, role: "button", tabindex: this.disabled ? '-1' : undefined, "aria-disabled": this.disabled ? 'true' : undefined }, content)
            : h(Host, { class: buttonClass, role: "button", disabled: this.disabled, "aria-disabled": this.disabled ? 'true' : undefined }, content));
    }
    async toggle() {
        this.active = true;
    }
    async dispose() {
        this.element.remove();
    }
    static get is() { return "bx-button"; }
    static get originalStyleUrls() { return {
        "$": ["bx-button.css"]
    }; }
    static get styleUrls() { return {
        "$": ["bx-button.css"]
    }; }
    static get properties() { return {
        "text": {
            "type": "string",
            "mutable": false,
            "complexType": {
                "original": "string",
                "resolved": "string",
                "references": {}
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": ""
            },
            "attribute": "text",
            "reflect": false
        },
        "variant": {
            "type": "string",
            "mutable": false,
            "complexType": {
                "original": "AdditionalVariants | Variants",
                "resolved": "AdditionalVariants | Variants.danger | Variants.dark | Variants.info | Variants.light | Variants.primary | Variants.secondary | Variants.success | Variants.warning",
                "references": {
                    "AdditionalVariants": {
                        "location": "import",
                        "path": "../../shared/bootstrap.dto"
                    },
                    "Variants": {
                        "location": "import",
                        "path": "../../shared/bootstrap.dto"
                    }
                }
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": ""
            },
            "attribute": "variant",
            "reflect": false,
            "defaultValue": "Variants.primary"
        },
        "size": {
            "type": "string",
            "mutable": false,
            "complexType": {
                "original": "Sizes",
                "resolved": "Sizes.large | Sizes.small",
                "references": {
                    "Sizes": {
                        "location": "import",
                        "path": "../../shared/bootstrap.dto"
                    }
                }
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": ""
            },
            "attribute": "size",
            "reflect": false
        },
        "outline": {
            "type": "boolean",
            "mutable": false,
            "complexType": {
                "original": "boolean",
                "resolved": "boolean",
                "references": {}
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": ""
            },
            "attribute": "outline",
            "reflect": false,
            "defaultValue": "false"
        },
        "block": {
            "type": "boolean",
            "mutable": false,
            "complexType": {
                "original": "boolean",
                "resolved": "boolean",
                "references": {}
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": ""
            },
            "attribute": "block",
            "reflect": false,
            "defaultValue": "false"
        },
        "active": {
            "type": "boolean",
            "mutable": false,
            "complexType": {
                "original": "boolean",
                "resolved": "boolean",
                "references": {}
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": ""
            },
            "attribute": "active",
            "reflect": false,
            "defaultValue": "false"
        },
        "disabled": {
            "type": "boolean",
            "mutable": false,
            "complexType": {
                "original": "boolean",
                "resolved": "boolean",
                "references": {}
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": ""
            },
            "attribute": "disabled",
            "reflect": false,
            "defaultValue": "false"
        },
        "link": {
            "type": "string",
            "mutable": false,
            "complexType": {
                "original": "string",
                "resolved": "string",
                "references": {}
            },
            "required": false,
            "optional": true,
            "docs": {
                "tags": [],
                "text": ""
            },
            "attribute": "link",
            "reflect": false
        },
        "target": {
            "type": "string",
            "mutable": false,
            "complexType": {
                "original": "string",
                "resolved": "string",
                "references": {}
            },
            "required": false,
            "optional": true,
            "docs": {
                "tags": [],
                "text": ""
            },
            "attribute": "target",
            "reflect": false
        }
    }; }
    static get methods() { return {
        "toggle": {
            "complexType": {
                "signature": "() => Promise<void>",
                "parameters": [],
                "references": {
                    "Promise": {
                        "location": "global"
                    }
                },
                "return": "Promise<void>"
            },
            "docs": {
                "text": "",
                "tags": []
            }
        },
        "dispose": {
            "complexType": {
                "signature": "() => Promise<void>",
                "parameters": [],
                "references": {
                    "Promise": {
                        "location": "global"
                    }
                },
                "return": "Promise<void>"
            },
            "docs": {
                "text": "",
                "tags": []
            }
        }
    }; }
    static get elementRef() { return "element"; }
}
